@@ -2,15 +2,16 @@
 #' 
 #' \code{xcorr} estimates the similarity of two spectrograms by means of cross-correlation
 #' @usage xcorr(X, wl =512, frange= NULL, ovlp=90, dens=0.9, bp= NULL, wn='hanning', 
-#' cor.method = "pearson", parallel = 1, path = NULL, pb = TRUE)
+#' cor.method = "pearson", parallel = 1, path = NULL, pb = TRUE, na.rm = FALSE,
+#'  dfrange = FALSE, cor.mat = TRUE)
 #' @param  X Data frame containing columns for sound files (sound.files), 
 #' selection number (selec), and start and end time of signal (start and end).
 #' @param wl A numeric vector of length 1 specifying the window length of the spectrogram, default 
 #' is 512.
 #' @param frange A numeric vector of length 2 setting the upper and lower frequency limits (in kHz) 
-#' in which to compare the signals. If not provided (\code{NULL}) the \code{\link{dfts}} function is used internally to define
-#' the higher and lower dominant frequency in the signals to be analyzed. This method is more adequate for pure tone
+#' in which to compare the signals. Must be provided. The \code{\link{dfts}} function can be used to determine this parameter if \code{dfrange = TRUE}. This method is more adequate for pure tone
 #' signals. Default is \code{NULL}.
+#' @param dfrange Logical. If \code{TRUE} the \code{\link{dfts}} function can is used to determine the frequency range in which to compare signals. 
 #' @param ovlp Numeric vector of length 1 specifying \% of overlap between two 
 #' consecutive windows, as in \code{\link[seewave]{spectro}}. Default is 90. High values of ovlp 
 #' slow down the function but produce more accurate results.
@@ -28,8 +29,12 @@
 #' If \code{NULL} (default) then the current working directory is used.
 #' @param pb Logical argument to control progress bar. Default is \code{TRUE}. Note that progress bar is only used
 #' when parallel = 1.
-#' @return A list that includes 1) a data frame with the correlation statistic for each "sliding" step, 2) a matrix with 
-#' the maximum (peak) correlation for each pairwise comparison, and 3) the frequency range.  
+#' @param na.rm Logical. If \code{TRUE} all NAs produced when pairwise cross-correlations failed are removed from the 
+#' results. This means that all selections with at least 1 cross-correlation that failed are excluded.
+#' @param cor.mat Logical. If \code{TRUE} only the correlation matrix is returned. Default is \code{TRUE}.
+#' @return If corr.mat is \code{TRUE} the function returns a matrix with 
+#' the maximum (peak) correlation for each pairwise comparison. Otherwise it will return a list that includes 1) a data frame with the correlation statistic for each "sliding" step, 2) a matrix with 
+#' the maximum correlation for each pairwise comparison, and 3) the frequency range. 
 #' @export
 #' @name xcorr
 #' @details This function calculates the pairwise similarity of multiple signals by means of spectrogram cross-correlation.
@@ -42,7 +47,7 @@
 #' from the awesome R package `monitoR`.   
 #' @examples
 #' \dontrun{
-#' #First set temporal working directory
+#' #First set temporary working directory
 #' setwd(tempdir())
 #' 
 #' #load data
@@ -62,8 +67,9 @@
 #' cross-correlation: tests of sensitivity. Bioacoustics 7(3): 209-234
 
 
-xcorr <- function(X = NULL, wl =512, frange= NULL, ovlp=90, dens=0.9, bp= NULL, 
-                   wn='hanning', cor.method = "pearson", parallel = 1, path = NULL, pb = TRUE)
+xcorr <- function(X = NULL, wl = 512, frange = NULL, ovlp = 90, dens = 0.9, bp = NULL, wn ='hanning', 
+                  cor.method = "pearson", parallel = 1, path = NULL,
+                  pb = TRUE, na.rm = FALSE, dfrange = FALSE, cor.mat = TRUE)
 {
   
   #check path to working directory
@@ -85,8 +91,9 @@ xcorr <- function(X = NULL, wl =512, frange= NULL, ovlp=90, dens=0.9, bp= NULL,
     if(!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")}}
   
   #if flim is not vector or length!=2 stop
-  if(!is.null(frange)) if(!is.vector(frange)) stop("'frange' must be a numeric vector of length 2") else
-      if(!length(frange) == 2) stop("'frange' must be a numeric vector of length 2")
+  if(is.null(frange) & !dfrange) stop("either 'frange' must be provided or 'dfrange' set to TRUE")
+  if(!is.null(frange) & !is.vector(frange)) stop("'frange' must be a numeric vector of length 2") else
+      if(!is.null(frange) & !length(frange) == 2) stop("'frange' must be a numeric vector of length 2")
   
   #if wl is not vector or length!=1 stop
   if(!is.numeric(wl)) stop("'wl' must be a numeric vector of length 1") else {
@@ -103,11 +110,12 @@ xcorr <- function(X = NULL, wl =512, frange= NULL, ovlp=90, dens=0.9, bp= NULL,
     if(!is.vector(dens)) stop("'dens' must be a numeric vector of length 1") else{
       if(!length(dens) == 1) stop("'dens' must be a numeric vector of length 1")}} 
   
-if(is.null(frange)) {df<-dfts(X, wl =300, img = FALSE, length.out = 50, parallel = parallel)
-  df<-df[, 3:ncol(df)]
-frq.lim = c(min(df), max(df))} else{
-  frq.lim = frange
-}
+# if frange was not provided the range is calculated with dominant frequency range  
+if(dfrange) {df <- dfts(X, wl =300, img = FALSE, length.out = 50, parallel = parallel, clip.edges = TRUE)
+  df <- df[, 3:ncol(df)]
+frq.lim = c(min(df, na.rm = TRUE), max(df, na.rm = TRUE))
+} else frq.lim = frange
+
 
   # If parallel is not numeric
   if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
@@ -119,18 +127,19 @@ frq.lim = c(min(df), max(df))} else{
     parallel <- 1}
   
   if(parallel > 1) 
-    lapp <- function(X, FUN) parallel::mclapply(X, FUN, mc.cores = parallel) else { 
-      if(pb)
-      lapp <- pbapply::pblapply else   lapp <- lapply
+    {
+    if(pb) lapp <- function(X, FUN) pbmcapply::pbmclapply(X, FUN, mc.cores = parallel) else
+    lapp <- function(X, FUN) parallel::mclapply(X, FUN, mc.cores = parallel)} else { 
+      if(pb) lapp <- pbapply::pblapply else   lapp <- lapply
   }  
           options(warn = 0)
           
 #create templates
-   if(parallel == 1 & pb) message("creating templates:")
+  if(any(parallel == 1, Sys.info()[1] == "Linux") & pb) message("creating templates:")
 ltemp <- lapp(1:nrow(X), function(x)
 {
    clip <- tuneR::readWave(filename = as.character(X$sound.files[x]),from = X$start[x], to=X$end[x],units = "seconds")
-   samp.rate <- clip@samp.rate
+  samp.rate <- clip@samp.rate
    
    # Fourier transform
    t.survey <- length(clip@left)/clip@samp.rate
@@ -139,7 +148,6 @@ ltemp <- lapp(1:nrow(X), function(x)
    # Filter amplitudes 
    t.bins <- fspec$time
    n.t.bins <- length(t.bins)
-   which.t.bins <- 1:n.t.bins
    which.frq.bins <- which(fspec$freq >= frq.lim[1] & fspec$freq <= frq.lim[2])
    frq.bins <- fspec$freq[which.frq.bins]
    n.frq.bins <- length(frq.bins)
@@ -192,85 +200,88 @@ ltemp <- lapp(1:nrow(X), function(x)
 
 names(ltemp) <- paste(X$sound.files,X$selec,sep = "-")
 
+#correlation function
+FUNXC <- function(i, cor.mat, survey ,wl, ovlp, wn, j, X)
+{
+  template <- ltemp[[i]]
+  
+  # Perform Fourier transform on survey
+  survey.spec <- seewave::spectro(wave = survey, wl = wl, ovlp = ovlp, wn = wn, plot = FALSE)
+  
+  # NTS arbitrary adjustment to eliminate -Inf
+  survey.spec$amp[is.infinite(survey.spec$amp)] <- min(survey.spec$amp[!is.infinite(survey.spec$amp)]) - 10
+  frq.bins <- survey.spec$freq
+  t.bins <- survey.spec$time
+  t.survey <- length(survey@left)/survey@samp.rate
+  t.step <- t.bins[2] - t.bins[1]
+  frq.step <- frq.bins[2] - frq.bins[1]
+  
+  pts <- template$pts[, c(2:1, 3)]
+  
+  # Adjust pts if step sizes differ
+  if(!isTRUE(all.equal(template$t.step, t.step, tolerance=t.step/1E4))) {
+    pts[, 't'] <- round(pts[, 't'] * template$t.step/t.step)
+  }
+  if(!isTRUE(all.equal(template$frq.step, frq.step, tolerance=frq.step/1E6))) {
+    pts[, 'frq'] <- round(pts[, 'frq'] * template$frq.step/frq.step)
+  }
+  
+  # Determine the frequency limits from the template points
+  frq.lim <- frq.bins[range(pts[, 'frq'])] 
+  
+  # Get number of time windows/bins in frequency domain data
+  n.t.survey <- length(survey.spec$time)
+  
+  #  down amplitude matrix based on filter frequencies 
+  which.frq.bins <- which(survey.spec$freq >= frq.lim[1] & survey.spec$freq <= frq.lim[2])
+  amp.survey <- survey.spec$amp[which.frq.bins, ]
+  
+  # Shift frq indices in pts. The t indices already start at 1.
+  pts[, 'frq'] <- pts[, 'frq'] - min(which.frq.bins) + 1
+  n.t.template <- max(pts[, 't'])
+  n.frq.template <- max(pts[, 'frq'])
+  
+  # Translate pts matrix of indices into a vector index so indexing is faster within the lapplyfun call
+  pts.v <- (pts[, 't'] - 1)*n.frq.template + pts[, 'frq']
+  amp.template <- pts[, 'amp']
+  amp.survey.v <- c(amp.survey)  
+  
+  # Perform analysis for each time value (bin) of survey 
+  # Starting time value (bin) of correlation window
+  c.win.start <- as.list(1:(n.t.survey-n.t.template)*n.frq.template) # Starting position of subset of each survey amp matrix  
+  score.survey <- unlist(
+    lapply(X=c.win.start, FUN=function(x) 
+    {
+      # Unpack columns of survey amplitude matrix for correlation analysis
+      cor(amp.template, amp.survey.v[x + pts.v], method=cor.method, use='complete.obs') 
+    }
+    )
+  )
+  
+  # Collect score results and time (center of time bins) in data frame
+  score.L <- data.frame(sound.file1 = paste(X$sound.files[j], X$selec[j], sep= "-"),sound.file2 = paste(template$sound.files,template$selec, sep= "-"), time=survey.spec$time[1:(n.t.survey-n.t.template)+n.t.template/2], 
+                        score=score.survey)
+  return(score.L)
+}
+
 #run cross-correlation
-if(parallel == 1 & pb) message("running cross-correlation:")
+if(any(parallel == 1, Sys.info()[1] == "Linux") & pb) message("running cross-correlation:")
 
 a<-lapp(1:(nrow(X)-1), function(j)
   {
     a <- tuneR::readWave(as.character(X$sound.files[j]), header = TRUE)
-  margin <-(X$end[j] - X$start[j])/2
+ 
+  margin <-(max(with(X, end[j:nrow(X)] - start[j:nrow(X)])))/2
   start <-X$start[j] - margin
-  if(start < 0) start <- 0
+  if(start < 0) {
+    end <-X$end[j] + margin -start[j]
+    start <- 0} else
   end <-X$end[j] + margin
   if(end > a$samples/a$sample.rate) end <- a$samples/a$sample.rate - 0.001
   
   survey<-tuneR::readWave(filename = as.character(X$sound.files[j]), from = start, to = end, units = "seconds")
   
-  FUNXC <- function(i)
-  {
-    template <- ltemp[[i]]
-    
-    # Perform Fourier transform on survey
-    survey.spec <- seewave::spectro(wave = survey, wl = wl, ovlp = ovlp, wn = wn, plot = FALSE)
-    
-    # NTS arbitrary adjustment to eliminate -Inf
-    survey.spec$amp[is.infinite(survey.spec$amp)] <- min(survey.spec$amp[!is.infinite(survey.spec$amp)]) - 10
-    frq.bins <- survey.spec$freq
-    t.bins <- survey.spec$time
-    t.survey <- length(survey@left)/survey@samp.rate
-    t.step <- t.bins[2] - t.bins[1]
-    frq.step <- frq.bins[2] - frq.bins[1]
-    
-    pts <- template$pts[, c(2:1, 3)]
-    
-    # Adjust pts if step sizes differ
-    if(!isTRUE(all.equal(template$t.step, t.step, tolerance=t.step/1E4))) {
-      pts[, 't'] <- round(pts[, 't'] * template$t.step/t.step)
-    }
-    if(!isTRUE(all.equal(template$frq.step, frq.step, tolerance=frq.step/1E6))) {
-      pts[, 'frq'] <- round(pts[, 'frq'] * template$frq.step/frq.step)
-    }
-    
-    # Determine the frequency limits from the template points
-    frq.lim <- frq.bins[range(pts[, 'frq'])] 
-    
-    # Get number of time windows/bins in frequency domain data
-    n.t.survey <- length(survey.spec$time)
-    
-    #  down amplitude matrix based on filter frequencies 
-    which.frq.bins <- which(survey.spec$freq >= frq.lim[1] & survey.spec$freq <= frq.lim[2])
-    amp.survey <- survey.spec$amp[which.frq.bins, ]
-    
-    # Shift frq indices in pts. The t indices already start at 1.
-    pts[, 'frq'] <- pts[, 'frq'] - min(which.frq.bins) + 1
-    n.t.template <- max(pts[, 't'])
-    n.frq.template <- max(pts[, 'frq'])
-    
-    # Translate pts matrix of indices into a vector index so indexing is faster within the lapplyfun call
-    pts.v <- (pts[, 't'] - 1)*n.frq.template + pts[, 'frq']
-    amp.template <- pts[, 'amp']
-    amp.survey.v <- c(amp.survey)  
-    
-    # Perform analysis for each time value (bin) of survey 
-    # Starting time value (bin) of correlation window
-    c.win.start <- as.list(1:(n.t.survey-n.t.template)*n.frq.template) # Starting position of subset of each survey amp matrix  
-    score.survey <- unlist(
-      lapply(X=c.win.start, FUN=function(x) 
-      {
-        # Unpack columns of survey amplitude matrix for correlation analysis
-        cor(amp.template, amp.survey.v[x + pts.v], method=cor.method, use='complete.obs') 
-      }
-      )
-    )
-    
-    # Collect score results and time (center of time bins) in data frame
-    score.L <- data.frame(sound.file1= paste(X$sound.files[j],X$selec[j], sep= "-"),sound.file2= paste(template$sound.files,template$selec, sep= "-"), time=survey.spec$time[1:(n.t.survey-n.t.template)+n.t.template/2], 
-                          score=score.survey)
-    return(score.L)
-  }
-  
-  
-  score.L <- lapply((1+j):length(ltemp), function(i) try(FUNXC(i), silent = T))
+  score.L <- lapply((1+j):length(ltemp), function(i) try(FUNXC(i, cor.mat, survey, wl, ovlp, wn,  j, X), silent = T))
   
   if(any(!sapply(score.L, is.data.frame))) {
   if(j != (length(ltemp)-1))
@@ -285,7 +296,14 @@ a<-lapp(1:(nrow(X)-1), function(j)
   } else  score.L[[1]] <- data.frame(sound.file1 = paste(X$sound.files[j], X$selec[j],sep = "-"), sound.file2 = paste(X$sound.files[j + 1], X$selec[j + 1], sep = "-"), time = 0, score = NA, stringsAsFactors = FALSE)
   }
   score.df <- do.call("rbind", score.L)
+
   
+    if(cor.mat)  
+{      score.df <- data.frame(dyad = paste(score.df$sound.file1,score.df$sound.file2,sep = "/"), score.df)
+  
+  # calculate maximum correlation values
+  score.df <- aggregate(as.data.frame(score.df$score), by = list(score.df$dyad), FUN = max)}
+      
 return(score.df)
   }
 )
@@ -294,30 +312,71 @@ return(score.df)
 b <- do.call("rbind", a)
 rm(a)
 
-b <- data.frame(dyad = paste(b$sound.file1,b$sound.file2,sep = "/"), b)
+if(!cor.mat)
+{b <- data.frame(dyad = paste(b$sound.file1,b$sound.file2,sep = "/"), b)
 
 # calculate maximum correlation values
 scores <- aggregate(as.data.frame(b$score), by = list(b$dyad), FUN = max)
+} else scores <- b
+
+
+names(scores)[2] <- "scores"
 
 #create a similarity matrix with the max xcorr
 mat <- matrix(nrow = nrow(X), ncol = nrow(X))
 mat[]<-1
 colnames(mat) <- rownames(mat) <- paste(X$sound.files, X$selec, sep = "-")
 
-for(i in 1:nrow(scores))
-{
-  mat[colnames(mat) == sapply(strsplit(as.character((scores$Group.1)), "/", fixed = TRUE), "[[", 1)[i], 
-      colnames(mat) == sapply(strsplit(as.character((scores$Group.1)), "/", fixed = TRUE), "[[", 2)[i]] <- scores$`b$score`[i]
-  
-  mat[colnames(mat) == sapply(strsplit(as.character((scores$Group.1)), "/", fixed = TRUE), "[[", 2)[i], 
-      colnames(mat) == sapply(strsplit(as.character((scores$Group.1)), "/", fixed = TRUE), "[[", 1)[i]] <- scores$`b$score`[i]
-}
+mat[lower.tri(mat, diag=FALSE)] <- scores$scores
+mat <- t(mat)
+mat[lower.tri(mat, diag=FALSE)] <- scores$scores
 
+
+##diagonal
+# diago <- sapply(1:nrow(X), function(j)
+# {
+#   a <- tuneR::readWave(as.character(X$sound.files[j]), header = TRUE)
+#   
+#   margin <-(max(with(X, end[j:nrow(X)] - start[j:nrow(X)])))/2
+#   start <-X$start[j] - margin
+#   if(start < 0) {
+#     end <-X$end[j] + margin -start[j]
+#     start <- 0} else
+#       end <-X$end[j] + margin
+#   if(end > a$samples/a$sample.rate) end <- a$samples/a$sample.rate
+#   
+#   survey<-tuneR::readWave(filename = as.character(X$sound.files[j]), from = start, to = end, units = "seconds")
+#   
+# 
+#   score.diag <- max(FUNXC(i = j, cor.mat = T,survey, wl, ovlp, wn, X =X, j)[,4], na.rm = TRUE)
+#    
+#   return(score.diag)
+# }
+# )
+# diag(mat) <- diago
+
+if(na.rm)
+{
+com.case <- intersect(rownames(mat)[stats::complete.cases(mat)], colnames(mat)[stats::complete.cases(t(mat))])
+if(length(which(is.na(mat))) > 0) 
+   warning(paste(length(which(is.na(mat))), "pairwise comparisons failed and were removed"))
+
+   #remove them from mat
+   mat <- mat[rownames(mat) %in% com.case, colnames(mat) %in% com.case]
+if(nrow(mat) == 0) stop("Not selections remained after removing NAs (na.rm = TRUE)")
+
+   #clean correlation data
+   if(!cor.mat)
+   b <- b[b$sound.file1 %in% com.case & b$sound.file2 %in% com.case, ]
+
+}  
+  
 #list results
-c <- list(b, mat, frq.lim)
+if(cor.mat) return(mat) else
+{c <- list(b, mat, frq.lim)
 names(c) <- c("correlation.data", "max.xcorr.matrix", "frq.lim") 
  
-return(c)
+return(c)}
 
-if(!is.null(path)) on.exit(setwd(wd))
+if(!is.null(path)) setwd(wd)
 }
